@@ -28,24 +28,24 @@
 
 class QSpinBox;
 
-namespace Kasten {
+
+namespace Kasten
+{
 
 class BytesPerGroupDialog : public QDialog
 {
-    Q_OBJECT
+  public:
+    explicit BytesPerGroupDialog( QWidget* parent = 0 );
 
-public:
-    explicit BytesPerGroupDialog(QWidget* parent = nullptr);
+    virtual ~BytesPerGroupDialog();
 
-    ~BytesPerGroupDialog() override;
+  public:
+    void setGroupedBytesCount( int groupedBytesCount );
 
-public:
-    void setGroupedBytesCount(int groupedBytesCount);
-
-public:
+  public:
     int groupedBytesCount() const;
 
-protected:
+  protected:
     QSpinBox* mGroupedBytesCountEdit;
 };
 
